==> nextcloud-app-news-15.4.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/zh_CN.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "请求失败，网络连接不可用！",
    "Request unauthorized. Are you logged in?" : "请求未通过认证。您登录成功了吗？",
    "Request forbidden. Are you an admin?" : "请求被拒绝。您是系统管理员吗？",
    "Token expired or app not enabled! Reload the page!" : "令牌过期或者应用没有启用！重新加载页面！",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "内部服务器错误！请检查您的 data/nextcloud.log 文件获取更多详细信息！",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "请求失败，Nextcloud 现处于维护模式！",
    "News folders" : "News 文件夹",
    "News" : "新闻",
    "An RSS/Atom feed reader" : "一个 RSS/Atom 订阅源阅读器",
    "The News app is an RSS/Atom feed reader for Nextcloud which can be synced with many mobile devices. A list of all clients and requirements can be found [in the README](https://github.com/nextcloud/news)\n\nBefore you update to a new version, [check the changelog](https://github.com/nextcloud/news/blob/master/CHANGELOG.md) to avoid surprises.\n\n**Important**: To enable feed updates you will need to enable either [Nextcloud system cron](https://docs.nextcloud.org/server/latest/admin_manual/configuration_server/background_jobs_configuration.html#cron) or use [an updater](https://github.com/nextcloud/news-updater) which uses the built in update API and disable cron updates. More information can be found [in the README](https://github.com/nextcloud/news)." : "新闻应用是 Nextcloud 上的一个 RSS/Atom 订阅源阅读器，可在多个移动设备间同步。客户端列表及安装需求请见 [自述文档] (https://github.com/nextcloud/news)\n\n在您升级到新版本前，[请查看变更日志](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)以避免意外。\n\n**重要**：要启用订阅源更新您需要启用[Nextcloud 系统计划任务](https://docs.nextcloud.com/server/10/admin_manual/configuration_server/background_jobs_configuration.html#cron)或者使用[一个更新器](https://github.com/nextcloud/news-updater)，它会调用集成的更新 API 并禁用计划任务更新。更多信息请见[自述文档](https://github.com/nextcloud/news)。",
    "Use system cron for updates" : "使用系统计划任务执行更新",
    "Disable this if you run a custom updater such as the Python updater included in the app." : "如果您运行了诸如应用自带的 Python 更新器，请禁用此项。",
    "Purge interval" : "清理间隔",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "从数据库中移除的订阅源和文件夹后的最小秒数；低于 60 秒的值将被忽略。",
    "Maximum read count per feed" : "每个订阅源的最大读取次数",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "定义每个订阅源可以读取的最大文章数，定时清理不会删除这些文章；如果在阅读后重新出现旧文章，请增加此值；负值（例如-1）将关闭此功能。",
    "Maximum redirects" : "最大重定向次数",
    "How many redirects the feed fetcher should follow." : "订阅源获取器最多应跟随多少次重定向。",
    "Feed fetcher timeout" : "订阅源获取器超时",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "最长的等待 RSS 或 Atom 订阅源加载的秒数；如果比这个时间更长更新将会中止。",
    "Explore Service URL" : "资源管理服务URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "如果给出，则会在查询订阅源部分中查询此服务的 URL 以显示订阅源。要回到内置的探索服务，请将此输入留空。",
    "For more information check the wiki." : "访问 Wiki 了解更多信息。",
    "Update interval" : "更新间隔",
    "Interval in seconds in which the feeds will be updated." : "订阅源更新的时间间隔（以秒为单位）。",
    "Saved" : "已保存",
    "Download" : "下载",
    "Close" : "关闭",
    "Subscribe to" : "订阅",
    "No articles available" : "没有文章可用",
    "No unread articles available" : "没有未读的文章可用",
    "Open website" : "打开网站",
    "Star article" : "文章加星",
    "Unstar article" : "取消文章加星",
    "Keep article unread" : "保持文章未读",
    "Remove keep article unread" : "取消保持文章未读",
    "by" : "发布者：",
    "from" : "来源",
    "Play audio" : "播放音频",
    "Download audio" : "下载音频",
    "Download video" : "下载视频",
    "Keyboard shortcut" : "键盘快捷键",
    "Description" : "描述",
    "right" : "右",
    "Jump to next article" : "跳到下一个文章",
    "left" : "左",
    "Jump to previous article" : "跳到上一个文章",
    "Toggle star article" : "切换文章加星状态",
    "Star article and jump to next one" : "文章加星并跳到下一个",
    "Toggle keep current article unread" : "切换保持文章未读状态设置",
    "Open article in new tab" : "在新标签页中打开文章",
    "Toggle expand article in compact view" : "在紧凑视图中展开文章",
    "Refresh" : "刷新",
    "Load next feed" : "加载下一个订阅源",
    "Load previous feed" : "加载上一个订阅源",
    "Load next folder" : "装载下一目录",
    "Load previous folder" : "装载前一目录",
    "Scroll to active navigation entry" : "滚动来激活浏览项目",
    "Focus search field" : "聚焦搜索域",
    "Mark current article's feed/folder read" : "标记当前文章的订阅源 / 文件夹为已读",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "检测到 Ajax 或 webcron 模式！您的订阅源将无法被更新！",
    "How to set up the operating system cron" : "如何设置操作系统定时任务",
    "Install and set up a faster parallel updater that uses the News app's update API" : "安装并设置一个更快速的更新程序，它使用新闻应用程序更新API",
    "Subscribe" : "订阅",
    "Web address" : "网络地址",
    "Feed exists already!" : "订阅源已存在！",
    "Folder" : "文件夹",
    "No folder" : "无文件夹",
    "New folder" : "新建文件夹",
    "Folder name" : "文件夹名称",
    "Go back" : "后退",
    "Folder exists already!" : "文件夹已经存在！",
    "Credentials" : "凭证",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth 认证只能被未加密保存！所有可以访问这个服务器的数据库的人都可以访问他们！",
    "Username" : "用户名",
    "Password" : "密码",
    "Autodiscover Feed" : "音频发现订阅源",
    "New Folder" : "新建文件夹",
    "Create" : "创建",
    "Explore" : "探索",
    "Update failed more than 50 times" : "更新失败超过 50 次",
    "Deleted feed" : "已删除的订阅源",
    "Undo delete feed" : "撤销删除订阅源",
    "Rename" : "重命名",
    "Menu" : "菜单",
    "Mark read" : "标记为已读",
    "Unpin from top" : "取消置顶",
    "Pin to top" : "固定在顶端",
    "Newest first" : "按时间顺序",
    "Oldest first" : "按时间倒序",
    "Default order" : "删除订阅",
    "Enable full text" : "启用全文模式",
    "Disable full text" : "禁用全文模式",
    "Unread updated" : "未读更新",
    "Ignore updated" : "忽略更新",
    "Open feed URL" : "打开订阅源网址",
    "Delete" : "删除",
    "Dismiss" : "忽略",
    "Collapse" : "折叠",
    "Deleted folder" : "删除文件夹",
    "Undo delete folder" : "取消删除文件夹",
    "Starred" : "已加星标",
    "Unread articles" : "未读文章",
    "All articles" : "全部文章",
    "Settings" : "设置",
    "Disable mark read through scrolling" : "禁用在滚动时标记文章为已读",
    "Compact view" : "紧凑视图",
    "Expand articles on key navigation" : "按键浏览时展开文章",
    "Show all articles" : "显示全部文章",
    "Reverse ordering (oldest on top)" : "逆序（最早文章先显示）",
    "Subscriptions (OPML)" : "订阅（OPML）",
    "Import" : "导入",
    "Export" : "导出",
    "Error when importing: File does not contain valid OPML" : "导入时出错：文件不包含有效的 OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "导入错误：OPML 未包含订阅源或文件夹",
    "Unread/Starred Articles" : "未读/已加星标文章",
    "Error when importing: file does not contain valid JSON" : "导入出错：文件包含非法的 JSON 数据",
    "Help" : "帮助",
    "Keyboard shortcuts" : "快捷键",
    "Documentation" : "文档",
    "Report a bug" : "报告  "
},
"nplurals=1; plural=0;");

==> nextcloud-app-news-16.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/zh_CN.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "请求失败，网络连接不可用！",
    "Request unauthorized. Are you logged in?" : "请求未通过认证。您登录成功了吗？",
    "Request forbidden. Are you an admin?" : "请求被拒绝。您是系统管理员吗？",
    "Token expired or app not enabled! Reload the page!" : "令牌过期或者应用没有启用！重新加载页面！",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "内部服务器错误！请检查您的 data/nextcloud.log 文件获取更多详细信息！",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "请求失败，Nextcloud 现处于维护模式！",
    "News feeds" : "新闻源",
    "Unread articles" : "未读文章",
    "News" : "新闻",
    "News folders" : "News 文件夹",
    "Shared with me" : "和我分享",
    "An RSS/Atom feed reader" : "一个 RSS/Atom 订阅源阅读器",
    "Use system cron for updates" : "使用系统计划任务执行更新",
    "Disable this if you use a custom updater." : "如果你使用自定义更新器则禁用它",
    "Purge interval" : "清理间隔",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "从数据库中移除的订阅源和文件夹后的最小秒数；低于 60 秒的值将被忽略。",
    "Maximum read count per feed" : "每个订阅源的最大读取次数",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "定义每个订阅源可以读取的最大文章数，定时清理不会删除这些文章；如果在阅读后重新出现旧文章，请增加此值；负值（例如-1）将关闭此功能。",
    "Maximum redirects" : "最大重定向次数",
    "How many redirects the feed fetcher should follow." : "订阅源获取器最多应跟随多少次重定向。",
    "Feed fetcher timeout" : "订阅源获取器超时",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "最长的等待 RSS 或 Atom 订阅源加载的秒数；如果比这个时间更长更新将会中止。",
    "Explore Service URL" : "资源管理服务URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "如果给出，则会在查询订阅源部分中查询此服务的 URL 以显示订阅源。要回到内置的探索服务，请将此输入留空。",
    "For more information check the wiki." : "访问 Wiki 了解更多信息。",
    "Update interval" : "更新间隔",
    "Interval in seconds in which the feeds will be updated." : "订阅源更新的时间间隔（以秒为单位）。",
    "For more information check the documentation." : "更多信息请见文档",
    "Saved" : "已保存",
    "Download" : "下载",
    "Close" : "关闭",
    "Subscribe to" : "订阅",
    "No articles available" : "没有文章可用",
    "No unread articles available" : "没有未读的文章可用",
    "Open website" : "打开网站",
    "Star article" : "文章加星",
    "Unstar article" : "取消文章加星",
    "Keep article unread" : "保持文章未读",
    "Remove keep article unread" : "取消保持文章未读",
    "Share" : "分享",
    "Share with users" : "与用户分享",
    "Username" : "用户名",
    "No users found" : "未找到用户",
    "Error while searching for users" : "收缩用户时出错",
    "Share on social media" : "在社交媒体上分享",
    "I wanted you to see this article" : "我想你看到这篇文章",
    "Check out this article" : "查看这篇文章",
    "by" : "发布者：",
    "from" : "来源",
    "shared by" : "分享者",
    "Play audio" : "播放音频",
    "Download audio" : "下载音频",
    "Download video" : "下载视频",
    "Keyboard shortcut" : "键盘快捷键",
    "Description" : "描述",
    "right" : "右",
    "Jump to next article" : "跳到下一个文章",
    "left" : "左",
    "Jump to previous article" : "跳到上一个文章",
    "Toggle star article" : "切换文章加星状态",
    "Star article and jump to next one" : "文章加星并跳到下一个",
    "Toggle keep current article unread" : "切换保持文章未读状态设置",
    "Open article in new tab" : "在新标签页中打开文章",
    "Toggle expand article in compact view" : "在紧凑视图中展开文章",
    "Refresh" : "刷新",
    "Load next feed" : "加载下一个订阅源",
    "Load previous feed" : "加载上一个订阅源",
    "Load next folder" : "装载下一目录",
    "Load previous folder" : "装载前一目录",
    "Scroll to active navigation entry" : "滚动来激活浏览项目",
    "Focus search field" : "聚焦搜索域",
    "Mark current article's feed/folder read" : "标记当前文章的订阅源 / 文件夹为已读",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "检测到 Ajax 或 webcron 模式！您的订阅源将无法被更新！",
    "How to set up the operating system cron" : "如何设置操作系统定时任务",
    "Install and set up a faster parallel updater that uses the News app's update API" : "安装并设置一个更快速的更新程序，它使用新闻应用程序更新API",
    "Subscribe" : "订阅",
    "Web address" : "网络地址",
    "Feed exists already!" : "订阅源已存在！",
    "Folder" : "文件夹",
    "No folder" : "无文件夹",
    "New folder" : "新建文件夹",
    "Folder name" : "文件夹名称",
    "Go back" : "后退",
    "Folder exists already!" : "文件夹已经存在！",
    "Credentials" : "凭证",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth 认证只能被未加密保存！所有可以访问这个服务器的数据库的人都可以访问他们！",
    "Password" : "密码",
    "Auto discover Feed" : "自动发现订阅源",
    "New Folder" : "新建文件夹",
    "Create" : "创建",
    "Explore" : "探索",
    "Update failed more than 50 times" : "更新失败超过 50 次",
    "Deleted feed" : "已删除的订阅源",
    "Undo delete feed" : "撤销删除订阅源",
    "Rename" : "重命名",
    "Menu" : "菜单",
    "Mark read" : "标记为已读",
    "Unpin from top" : "取消置顶",
    "Pin to top" : "固定在顶端",
    "Newest first" : "按时间顺序",
    "Oldest first" : "按时间倒序",
    "Default order" : "删除订阅",
    "Enable full text" : "启用全文模式",
    "Disable full text" : "禁用全文模式",
    "Unread updated" : "未读更新",
    "Ignore updated" : "忽略更新",
    "Open feed URL" : "打开订阅源网址",
    "Delete" : "删除",
    "Dismiss" : "忽略",
    "Collapse" : "折叠",
    "Deleted folder" : "删除文件夹",
    "Undo delete folder" : "取消删除文件夹",
    "Starred" : "已加星标",
    "All articles" : "全部文章",
    "Settings" : "设置",
    "Disable mark read through scrolling" : "禁用在滚动时标记文章为已读",
    "Compact view" : "紧凑视图",
    "Expand articles on key navigation" : "按键浏览时展开文章",
    "Show all articles" : "显示全部文章",
    "Reverse ordering (oldest on top)" : "逆序（最早文章先显示）",
    "Subscriptions (OPML)" : "订阅（OPML）",
    "Import" : "导入",
    "Export" : "导出",
    "Error when importing: File does not contain valid OPML" : "导入时出错：文件不包含有效的 OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "导入错误：OPML 未包含订阅源或文件夹",
    "Unread/Starred Articles" : "未读/已加星标文章",
    "Error when importing: file does not contain valid JSON" : "导入出错：文件包含非法的 JSON 数据",
    "Help" : "帮助",
    "Keyboard shortcuts" : "快捷键",
    "Documentation" : "文档",
    "Report a bug" : "报告  "
},
"nplurals=1; plural=0;");
